@@ -1,9 +1,6 @@
 test_that("data conversion", {
-  skip("h2o server issues with testthat")
-
-  agua:::h2o_start()
-  on.exit(h2o::h2o.shutdown(prompt = FALSE))
-  skip_if(!h2o_running())
+  skip_if(!interactive())
+  h2o_start()
 
   expect_silent(cars_1 <- as_h2o(mtcars))
   expect_equal(class(cars_1$data), "H2OFrame")
@@ -13,9 +10,10 @@ test_that("data conversion", {
 
 
 test_that("server functions", {
-  skip("h2o server issues with testthat")
+  # skip("h2o server issues with testthat")
+  skip_if(!interactive())
 
-  expect_silent(agua:::h2o_start())
+  expect_silent(agua::h2o_start())
   expect_true(h2o_running())
   h2o::h2o.shutdown(prompt = FALSE)
   expect_false(h2o_running())
